[gnus git] branch master updated: m0-11-97-g3322b95 =1= * registry.el (registry-db): Fix default registry-db max-size.

Ted <[email protected]> Thu, 18 Dec 2014 20:49:49 +0100
Newsgroups gmane.emacs.gnus.cvs
Message-ID <[email protected]>
       via  3322b953e78d1714443478d212c633874226d190 (commit)
      from  af0fe49bfe085fa79608eed261a7b7b04c8a86b6 (commit)


- Log -----------------------------------------------------------------
commit 3322b953e78d1714443478d212c633874226d190
Author: Ted Zlatanov <[email protected]>
Date:   Thu Dec 18 14:49:33 2014 -0500

    * registry.el (registry-db): Fix default registry-db max-size.

diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index 192a13d..072dd08 100644
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -1,3 +1,7 @@
+2014-12-18  Teodor Zlatanov  <[email protected]>
+
+	* registry.el (registry-db): Fix default registry-db max-size.
+
 2014-12-18  Eric Abrahamsen <[email protected]>
 
 	* registry.el (registry-db): Consolidate the :max-hard and :max-soft
diff --git a/lisp/registry.el b/lisp/registry.el
index d949e7a..162e876 100644
--- a/lisp/registry.el
+++ b/lisp/registry.el
@@ -27,7 +27,7 @@
 
 ;; version: a float
 
 ;; max-size: an integer, default 50000
 
 ;; prune-factor: a float between 0 and 1, default 0.1
 
@@ -110,7 +110,7 @@
             :type (or null float)
             :documentation "The registry version.")
    (max-size :initarg :max-size
-             :initform most-positive-fixnum
+             :initform 5000000
              :type integer
              :custom integer
              :documentation "The maximum number of registry entries.")

-----------------------------------------------------------------------
@@ -27,7 +27,7 @@
 ;; version: a float
 
-;; max-size: an integer, default 50000
+;; max-size: an integer, default 5000000
 
 ;; prune-factor: a float between 0 and 1, default 0.1
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we listed those
revisions in full, above.

Summary of changes:
 lisp/ChangeLog   |    4 ++++
 lisp/registry.el |    4 ++--
 2 files changed, 6 insertions(+), 2 deletions(-)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Gnus Project".

The branch, master has been updated


hooks/post-receive
-- 
Gnus Project